@@ -213,7 +213,7 @@ func createFormFile(w *multipart.Writer, workingDir string, mountPath string) er
 		return err
 	}
 	if fileStat.Size() > maxFileSize {
-		return errors.New("file exceeds limit of 10MB")
+		return errors.Newf("file %q exceeds limit of 10MB", mountPath)
 	}
 
 	filePath, fileName := filepath.Split(mountPath)
